@@ -22,6 +22,8 @@
 
 #include "writtenpracticewidget.h"
 
+#include <KRandomSequence>
+
 namespace Ui
 {
 class WrittenPracticeWidget;
@@ -53,6 +55,7 @@ private:
     QString m_question;
     QList<int> m_positions;
     QPixmap m_pixmap;
+    KRandomSequence m_randomSequence;
     QFont m_solutionFont;
 };
 
